---
name: Question
about: A question about this project
title: "QUEST: "
labels: question

---

# Description
A clear and concise summary of your query

## Example code (optional)
If relevant, include sample code, images, or files so that others can understand
the full context of your question.

## Configuration
 - OS: [e.g. Hal]
 - Version [e.g. Python 3.47]
 - Other details about your setup that could be relevant
